@@ -1,7 +1,5 @@
 #[macro_use]
 extern crate lazy_static;
-extern crate pathfinding;
-extern crate rand;
 
 use pathfinding::prelude::{absdiff, astar, idastar};
 use rand::prelude::*;
@@ -14,7 +12,7 @@ const SIDE: u8 = 3;
 const SIDE: u8 = 4;
 const LIMIT: usize = (SIDE * SIDE) as usize;
 
-#[cfg_attr(feature = "cargo-clippy", allow(derive_hash_xor_eq))]
+#[allow(clippy::derive_hash_xor_eq)]
 #[derive(Clone, Debug, Hash)]
 struct Game {
     positions: [u8; LIMIT], // Correct position of piece at every index
